@@ -4,4 +4,4 @@ from typing import Tuple
 
 
 def dummy_batch(m: nn.Module, size: Tuple) -> torch.Tensor:
-    return next(m.parameters()).new_tensor(*size).requires_grad_(False).uniform_(-1., 1.)
+    return next(m.parameters()).new_empty(size=size).requires_grad_(False).uniform_(-1., 1.)
